ImageCompress class

Constructors

ImageCompress()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

contain({required String filePath, CompressFormat? compressFormat, int? maxWidth, int? maxHeight, int? quality, FilterType? samplingFilter, int? speed}) Future<Uint8List>
fitHeight({required String filePath, CompressFormat? compressFormat, int? maxHeight, int? quality, FilterType? samplingFilter, int? speed}) Future<Uint8List>
fitWidth({required String filePath, CompressFormat? compressFormat, int? maxWidth, int? quality, FilterType? samplingFilter, int? speed}) Future<Uint8List>